/* Copyright 2011-2013 Google Inc.
 * Copyright 2013 mike wakerly <opensource@hoho.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA.
 *
 * Project home page: https://github.com/mik3y/usb-serial-for-android
 */

package com.hoho.android.usbserial.driver;

/**
 * Registry of USB vendor/product ID constants.
 *
 * Culled from various sources; see
 * <a href="http://www.linux-usb.org/usb.ids">usb.ids</a> for one listing.
 *
 * @author mike wakerly (opensource@hoho.com)
 */
public final class UsbId {

    public static final int VENDOR_FTDI = 0x0403;
    public static final int FTDI_FT232R = 0x6001;
    public static final int FTDI_FT231X = 0x6015;

    public static final int VENDOR_ATMEL = 0x03EB;
    public static final int ATMEL_LUFA_CDC_DEMO_APP = 0x2044;

    public static final int VENDOR_ARDUINO = 0x2341;
    public static final int ARDUINO_UNO = 0x0001;
    public static final int ARDUINO_MEGA_2560 = 0x0010;
    public static final int ARDUINO_SERIAL_ADAPTER = 0x003b;
    public static final int ARDUINO_MEGA_ADK = 0x003f;
    public static final int ARDUINO_MEGA_2560_R3 = 0x0042;
    public static final int ARDUINO_UNO_R3 = 0x0043;
    public static final int ARDUINO_MEGA_ADK_R3 = 0x0044;
    public static final int ARDUINO_SERIAL_ADAPTER_R3 = 0x0044;
    public static final int ARDUINO_LEONARDO = 0x8036;

    public static final int VENDOR_VAN_OOIJEN_TECH = 0x16c0;
    public static final int VAN_OOIJEN_TECH_TEENSYDUINO_SERIAL = 0x0483;

    public static final int VENDOR_LEAFLABS = 0x1eaf;
    public static final int LEAFLABS_MAPLE = 0x0004;

    public static final int VENDOR_SILABS = 0x10c4;
    public static final int SILABS_CP2102 = 0xea60;
    public static final int SILABS_CP2105 = 0xea70;
    public static final int SILABS_CP2108 = 0xea71;
    public static final int SILABS_CP2110 = 0xea80;

    public static final int VENDOR_PROLIFIC = 0x067b;
    public static final int PROLIFIC_PL2303 = 0x2303;

    public static final int VENDOR_SAGEM = 0x079b;
    public static final int SAGEM_GENERIC = 0x0028;
    
    public static final int VENDOR_INGENICO = 0x0b00;
    public static final int INGENICO_IPP = 0x0060;          // iPP4xx/320/350
    public static final int INGENICO_ISC = 0x0061;          // iSC350/480
    public static final int INGENICO_ISC2xx = 0x0062;       // iSC2xx
    public static final int INGENICO_IWL = 0x0064;          // iWL2xx/350
    public static final int INGENICO_ICT = 0x0066;          // iCT2xx
    public static final int INGENICO_IST = 0x0057;          // iST1xx/iUC1xx/iUP250
    public static final int INGENICO_MOVE5000 = 0x0052;     // Move5000
    public static final int INGENICO_MOVE3500 = 0x0053;     // Move3500
    public static final int INGENICO_DESK3xxx = 0x0054;     // Desk3xxx
    public static final int INGENICO_MOVE2500 = 0x0055;     // Move2500
    public static final int INGENICO_DESK3200 = 0x0063;     // Desk3200
    public static final int INGENICO_DESK5000 = 0x0080;     // Desk5000
    public static final int INGENICO_LANE5000 = 0x0081;     // Lane5000
    
    public static final int INGENICO_LANE7xxx = 0x0056;     // Lane7xxx
    public static final int INGENICO_ISC4xx = 0x0063;       // iSC4xx
    public static final int INGENICO_LANE8xxx = 0x0082;     // Lane8xxx
    public static final int INGENICO_LINK2xxx = 0x0083;     // Link2xxx
    
    private UsbId() {
        throw new IllegalAccessError("Non-instantiable class.");
    }

}
